@@ -1,5 +1,5 @@
 import pytest
-from spotPython.light.netlightregression import NetLightRegression
+from spotPython.light.regression.netlightregression import NetLightRegression
 from spotPython.utils.init import fun_control_init
 from spotPython.hyperdict.light_hyper_dict import LightHyperDict
 from spotPython.hyperparameters.values import add_core_model_to_fun_control
